OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Impossible de cargar lo modèl",
    "Saved" : "Salvat",
    "Reset" : "Reïnicializar",
    "Sharing email - public link shares (HTML)" : "Email de partiment - partiment per ligam public (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "Email de partiment - partiment per ligam public (version tèxte simple alternativa)",
    "Sharing email (HTML)" : "Email de partiment (HTML)",
    "Sharing email (plain text fallback)" : "Email de partiment (version tèxte simple alternativa)",
    "Lost password mail" : "Messatge mandat en cas de pèrda del senhal",
    "New user email (HTML)" : "Email pels utilizaires novèls (HTML)",
    "New user email (plain text fallback)" : "Email pels utilizaires novèls (version tèxte simple alternativa)",
    "Activity notification mail" : "Email de notificacion d'activitat",
    "Mail Templates" : "Modèls de mail",
    "Theme" : "Tèma",
    "Template" : "Modèl",
    "Please choose a template" : "Causissètz un modèl",
    "Save" : "Salvar"
},
"nplurals=2; plural=(n > 1);");
